//
// uncia - a big cat
// Copyright (C) 2009 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 3, as
// published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program. If not, see <http://www.gnu.org/licenses/>.
//

#ifndef LIBUNCIA_INPUT_FILTER_APPLE_H
#define LIBUNCIA_INPUT_FILTER_APPLE_H

#include <libuncia/input/filter.h>
#include <libuncia/istream.h>

namespace libuncia
{
    /**
      * The input_filter_apple class is used to represent an input
      * filter which translates Apple Macintosh line termination (CR)
      * into ANSI C line termination (LF).
      */
    class input_filter_apple:
        public input_filter
    {
    public:
        /**
          * The destructor.
          */
        virtual ~input_filter_apple();

    private:
        /**
          * The constructor.  It is private on purpose, use the #create
          * class method instead.
          *
          * @param deeper
          *     The data source to be filtered.
          */
        input_filter_apple(const pointer &deeper);

    public:
        /**
          * The create class method is used to create new dynmically
          * allocated instances of this class.
          *
          * @param deeper
          *     The data source to be filtered.
          */
        static pointer create(const pointer &deeper);

    protected:
        // See base class for documentation.
        ssize_t read(void *data, size_t size);

    private:
        /**
          * The default constructor.  Do not use.
          */
        input_filter_apple();

        /**
          * The copy constructor.  Do not use.
          *
          * @param rhs
          *     The right hand side of the initialization.
          */
        input_filter_apple(const input_filter_apple &rhs);

        /**
          * The assignment operator.  Do not use.
          *
          * @param rhs
          *     The right hand side of the assignment.
          */
        input_filter_apple &operator=(const input_filter_apple &rhs);
    };
}

#endif // LIBUNCIA_INPUT_FILTER_APPLE_H
